<?php

if ( ! function_exists( 'leonie_core_add_fonts_options' ) ) {
	/**
	 * Function that add options for this module
	 */
	function leonie_core_add_fonts_options() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => LEONIE_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'fonts',
				'title'       => esc_html__( 'Fonts', 'leonie-core' ),
				'description' => esc_html__( 'Global Fonts Options', 'leonie-core' ),
				'icon'        => 'fa fa-cog',
			)
		);

		if ( $page ) {
			$page->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_enable_google_fonts',
					'title'         => esc_html__( 'Enable Google Fonts', 'leonie-core' ),
					'default_value' => 'yes',
					'args'          => array(
						'custom_class' => 'qodef-enable-google-fonts',
					),
				)
			);

			$google_fonts_section = $page->add_section_element(
				array(
					'name'       => 'qodef_google_fonts_section',
					'title'      => esc_html__( 'Google Fonts Options', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_enable_google_fonts' => array(
								'values'        => 'yes',
								'default_value' => '',
							),
						),
					),
				)
			);

			$page_repeater = $google_fonts_section->add_repeater_element(
				array(
					'name'        => 'qodef_choose_google_fonts',
					'title'       => esc_html__( 'Google Fonts to Include', 'leonie-core' ),
					'description' => esc_html__( 'Choose Google Fonts which you want to use on your website', 'leonie-core' ),
					'button_text' => esc_html__( 'Add New Google Font', 'leonie-core' ),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type'  => 'googlefont',
					'name'        => 'qodef_choose_google_font',
					'title'       => esc_html__( 'Google Font', 'leonie-core' ),
					'description' => esc_html__( 'Choose Google Font', 'leonie-core' ),
					'args'        => array(
						'include' => 'google-fonts',
					),
				)
			);

			$google_fonts_section->add_field_element(
				array(
					'field_type'  => 'checkbox',
					'name'        => 'qodef_google_fonts_weight',
					'title'       => esc_html__( 'Google Fonts Weight', 'leonie-core' ),
					'description' => esc_html__( 'Choose a default Google Fonts weights for your website. Impact on page load time', 'leonie-core' ),
					'options'     => array(
						'100'  => esc_html__( '100 Thin', 'leonie-core' ),
						'100i' => esc_html__( '100 Thin Italic', 'leonie-core' ),
						'200'  => esc_html__( '200 Extra-Light', 'leonie-core' ),
						'200i' => esc_html__( '200 Extra-Light Italic', 'leonie-core' ),
						'300'  => esc_html__( '300 Light', 'leonie-core' ),
						'300i' => esc_html__( '300 Light Italic', 'leonie-core' ),
						'400'  => esc_html__( '400 Regular', 'leonie-core' ),
						'400i' => esc_html__( '400 Regular Italic', 'leonie-core' ),
						'500'  => esc_html__( '500 Medium', 'leonie-core' ),
						'500i' => esc_html__( '500 Medium Italic', 'leonie-core' ),
						'600'  => esc_html__( '600 Semi-Bold', 'leonie-core' ),
						'600i' => esc_html__( '600 Semi-Bold Italic', 'leonie-core' ),
						'700'  => esc_html__( '700 Bold', 'leonie-core' ),
						'700i' => esc_html__( '700 Bold Italic', 'leonie-core' ),
						'800'  => esc_html__( '800 Extra-Bold', 'leonie-core' ),
						'800i' => esc_html__( '800 Extra-Bold Italic', 'leonie-core' ),
						'900'  => esc_html__( '900 Ultra-Bold', 'leonie-core' ),
						'900i' => esc_html__( '900 Ultra-Bold Italic', 'leonie-core' ),
					),
				)
			);

			$google_fonts_section->add_field_element(
				array(
					'field_type'  => 'checkbox',
					'name'        => 'qodef_google_fonts_subset',
					'title'       => esc_html__( 'Google Fonts Style', 'leonie-core' ),
					'description' => esc_html__( 'Choose a default Google Fonts style for your website. Impact on page load time', 'leonie-core' ),
					'options'     => array(
						'latin'        => esc_html__( 'Latin', 'leonie-core' ),
						'latin-ext'    => esc_html__( 'Latin Extended', 'leonie-core' ),
						'cyrillic'     => esc_html__( 'Cyrillic', 'leonie-core' ),
						'cyrillic-ext' => esc_html__( 'Cyrillic Extended', 'leonie-core' ),
						'greek'        => esc_html__( 'Greek', 'leonie-core' ),
						'greek-ext'    => esc_html__( 'Greek Extended', 'leonie-core' ),
						'vietnamese'   => esc_html__( 'Vietnamese', 'leonie-core' ),
					),
				)
			);

			$page_repeater = $page->add_repeater_element(
				array(
					'name'        => 'qodef_custom_fonts',
					'title'       => esc_html__( 'Custom Fonts', 'leonie-core' ),
					'description' => esc_html__( 'Add custom fonts', 'leonie-core' ),
					'button_text' => esc_html__( 'Add New Custom Font', 'leonie-core' ),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type' => 'file',
					'name'       => 'qodef_custom_font_ttf',
					'title'      => esc_html__( 'Custom Font TTF', 'leonie-core' ),
					'args'       => array(
						'allowed_type' => 'application/octet-stream',
					),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type' => 'file',
					'name'       => 'qodef_custom_font_otf',
					'title'      => esc_html__( 'Custom Font OTF', 'leonie-core' ),
					'args'       => array(
						'allowed_type' => 'application/octet-stream',
					),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type' => 'file',
					'name'       => 'qodef_custom_font_woff',
					'title'      => esc_html__( 'Custom Font WOFF', 'leonie-core' ),
					'args'       => array(
						'allowed_type' => 'application/octet-stream',
					),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type' => 'file',
					'name'       => 'qodef_custom_font_woff2',
					'title'      => esc_html__( 'Custom Font WOFF2', 'leonie-core' ),
					'args'       => array(
						'allowed_type' => 'application/octet-stream',
					),
				)
			);

			$page_repeater->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_custom_font_name',
					'title'      => esc_html__( 'Custom Font Name', 'leonie-core' ),
				)
			);

			// Hook to include additional options after module options
			do_action( 'leonie_core_action_after_page_fonts_options_map', $page );
		}
	}

	add_action( 'leonie_core_action_default_options_init', 'leonie_core_add_fonts_options', leonie_core_get_admin_options_map_position( 'fonts' ) );
}
