<?php

if ( ! function_exists( 'leonie_core_add_general_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function leonie_core_add_general_options( $page ) {

		if ( $page ) {
			$page->add_field_element(
				array(
					'field_type'  => 'color',
					'name'        => 'qodef_main_color',
					'title'       => esc_html__( 'Main Color', 'leonie-core' ),
					'description' => esc_html__( 'Choose the most dominant theme color', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'color',
					'name'        => 'qodef_page_background_color',
					'title'       => esc_html__( 'Page Background Color', 'leonie-core' ),
					'description' => esc_html__( 'Set background color', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_page_background_image',
					'title'       => esc_html__( 'Page Background Image', 'leonie-core' ),
					'description' => esc_html__( 'Set background image', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_page_background_repeat',
					'title'       => esc_html__( 'Page Background Image Repeat', 'leonie-core' ),
					'description' => esc_html__( 'Set background image repeat', 'leonie-core' ),
					'options'     => array(
						''          => esc_html__( 'Default', 'leonie-core' ),
						'no-repeat' => esc_html__( 'No Repeat', 'leonie-core' ),
						'repeat'    => esc_html__( 'Repeat', 'leonie-core' ),
						'repeat-x'  => esc_html__( 'Repeat-x', 'leonie-core' ),
						'repeat-y'  => esc_html__( 'Repeat-y', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_page_background_size',
					'title'       => esc_html__( 'Page Background Image Size', 'leonie-core' ),
					'description' => esc_html__( 'Set background image size', 'leonie-core' ),
					'options'     => array(
						''        => esc_html__( 'Default', 'leonie-core' ),
						'contain' => esc_html__( 'Contain', 'leonie-core' ),
						'cover'   => esc_html__( 'Cover', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_page_background_attachment',
					'title'       => esc_html__( 'Page Background Image Attachment', 'leonie-core' ),
					'description' => esc_html__( 'Set background image attachment', 'leonie-core' ),
					'options'     => array(
						''       => esc_html__( 'Default', 'leonie-core' ),
						'fixed'  => esc_html__( 'Fixed', 'leonie-core' ),
						'scroll' => esc_html__( 'Scroll', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_page_content_padding',
					'title'       => esc_html__( 'Page Content Padding', 'leonie-core' ),
					'description' => esc_html__( 'Set padding that will be applied for page content in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_page_content_padding_mobile',
					'title'       => esc_html__( 'Page Content Padding Mobile', 'leonie-core' ),
					'description' => esc_html__( 'Set padding that will be applied for page content on mobile screens (1024px and below) in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_boxed',
					'title'         => esc_html__( 'Boxed Layout', 'leonie-core' ),
					'description'   => esc_html__( 'Set boxed layout', 'leonie-core' ),
					'default_value' => 'no',
				)
			);

			$boxed_section = $page->add_section_element(
				array(
					'name'       => 'qodef_boxed_section',
					'title'      => esc_html__( 'Boxed Layout Section', 'leonie-core' ),
					'dependency' => array(
						'hide' => array(
							'qodef_boxed' => array(
								'values'        => 'no',
								'default_value' => '',
							),
						),
					),
				)
			);

			$boxed_section->add_field_element(
				array(
					'field_type'  => 'color',
					'name'        => 'qodef_boxed_background_color',
					'title'       => esc_html__( 'Boxed Background Color', 'leonie-core' ),
					'description' => esc_html__( 'Set boxed background color', 'leonie-core' ),
				)
			);

			$boxed_section->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_boxed_background_pattern',
					'title'       => esc_html__( 'Boxed Background Pattern', 'leonie-core' ),
					'description' => esc_html__( 'Set boxed background pattern', 'leonie-core' ),
				)
			);

			$boxed_section->add_field_element(
				array(
					'field_type'  => 'select',
					'name'        => 'qodef_boxed_background_pattern_behavior',
					'title'       => esc_html__( 'Boxed Background Pattern Behavior', 'leonie-core' ),
					'description' => esc_html__( 'Set boxed background pattern behavior', 'leonie-core' ),
					'options'     => array(
						'fixed'  => esc_html__( 'Fixed', 'leonie-core' ),
						'scroll' => esc_html__( 'Scroll', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'    => 'yesno',
					'name'          => 'qodef_passepartout',
					'title'         => esc_html__( 'Passepartout', 'leonie-core' ),
					'description'   => esc_html__( 'Enabling this option will display a passepartout around website content', 'leonie-core' ),
					'default_value' => 'no',
				)
			);

			$passepartout_section = $page->add_section_element(
				array(
					'name'       => 'qodef_passepartout_section',
					'title'      => esc_html__( 'Passepartout Section', 'leonie-core' ),
					'dependency' => array(
						'hide' => array(
							'qodef_passepartout' => array(
								'values'        => 'no',
								'default_value' => '',
							),
						),
					),
				)
			);

			$passepartout_section->add_field_element(
				array(
					'field_type'  => 'color',
					'name'        => 'qodef_passepartout_color',
					'title'       => esc_html__( 'Passepartout Color', 'leonie-core' ),
					'description' => esc_html__( 'Choose background color for passepartout', 'leonie-core' ),
				)
			);

			$passepartout_section->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_passepartout_image',
					'title'       => esc_html__( 'Passepartout Background Image', 'leonie-core' ),
					'description' => esc_html__( 'Set background image for passepartout', 'leonie-core' ),
				)
			);

			$passepartout_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_passepartout_size',
					'title'       => esc_html__( 'Passepartout Size', 'leonie-core' ),
					'description' => esc_html__( 'Enter size amount for passepartout', 'leonie-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px or %', 'leonie-core' ),
					),
				)
			);

			$passepartout_section->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_passepartout_size_responsive',
					'title'       => esc_html__( 'Passepartout Responsive Size', 'leonie-core' ),
					'description' => esc_html__( 'Enter size amount for passepartout for smaller screens (1024px and below)', 'leonie-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px or %', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_content_width',
					'title'         => esc_html__( 'Initial Width of Content', 'leonie-core' ),
					'description'   => esc_html__( 'Choose the initial width of content which is in grid (applies to pages set to "Default Template" and rows set to "In Grid")', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'content_width', false ),
					'default_value' => '1100',
				)
			);

            $page->add_field_element(
                array(
                    'field_type'    => 'yesno',
                    'name'          => 'qodef_disable_images_lazy_loading',
                    'title'         => esc_html__( 'Disable Images Lazy Loading', 'leonie-core' ),
                    'description'   => esc_html__( 'Note that some images that have hover animation will not load if this option is turned off', 'leonie-core' ),
                    'options'       => leonie_core_get_select_type_options_pool( 'yes_no', false ),
                    'default_value' => 'yes'
                )
            );

			// Hook to include additional options after module options
			do_action( 'leonie_core_action_after_general_options_map', $page );

			$page->add_field_element(
				array(
					'field_type'  => 'textarea',
					'name'        => 'qodef_custom_js',
					'title'       => esc_html__( 'Custom JS', 'leonie-core' ),
					'description' => esc_html__( 'Enter your custom JavaScript here', 'leonie-core' ),
				)
			);
		}
	}

	add_action( 'leonie_core_action_default_options_init', 'leonie_core_add_general_options', leonie_core_get_admin_options_map_position( 'general' ) );
}
