<?php

if ( ! function_exists( 'leonie_core_add_logo_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function leonie_core_add_logo_options() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => LEONIE_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'logo',
				'icon'        => 'fa fa-cog',
				'title'       => esc_html__( 'Logo', 'leonie-core' ),
				'description' => esc_html__( 'Global Logo Options', 'leonie-core' ),
				'layout'      => 'tabbed',
			)
		);

		if ( $page ) {

			$header_tab = $page->add_tab_element(
				array(
					'name'        => 'tab-header',
					'icon'        => 'fa fa-cog',
					'title'       => esc_html__( 'Header Logo Options', 'leonie-core' ),
					'description' => esc_html__( 'Set options for initial headers', 'leonie-core' ),
				)
			);

			$header_tab->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_logo_height',
					'title'       => esc_html__( 'Logo Height', 'leonie-core' ),
					'description' => esc_html__( 'Enter logo height', 'leonie-core' ),
					'args'        => array(
						'suffix' => esc_html__( 'px', 'leonie-core' ),
					),
				)
			);

			$header_tab->add_field_element(
				array(
					'field_type'  => 'text',
					'name'        => 'qodef_logo_padding',
					'title'       => esc_html__( 'Logo Padding', 'leonie-core' ),
					'description' => esc_html__( 'Enter logo padding value (top right bottom left)', 'leonie-core' ),
				)
			);

			$header_tab->add_field_element(
				array(
					'field_type'    => 'image',
					'name'          => 'qodef_logo_main',
					'title'         => esc_html__( 'Logo - Main', 'leonie-core' ),
					'description'   => esc_html__( 'Choose main logo image', 'leonie-core' ),
					'default_value' => defined( 'LEONIE_ASSETS_ROOT' ) ? LEONIE_ASSETS_ROOT . '/img/logo.png' : '',
					'multiple'      => 'no',
				)
			);

			$header_tab->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_logo_dark',
					'title'       => esc_html__( 'Logo - Dark', 'leonie-core' ),
					'description' => esc_html__( 'Choose dark logo image', 'leonie-core' ),
					'multiple'    => 'no',
				)
			);

			$header_tab->add_field_element(
				array(
					'field_type'  => 'image',
					'name'        => 'qodef_logo_light',
					'title'       => esc_html__( 'Logo - Light', 'leonie-core' ),
					'description' => esc_html__( 'Choose light logo image', 'leonie-core' ),
					'multiple'    => 'no',
				)
			);

			// Hook to include additional options after module options
			do_action( 'leonie_core_action_after_header_logo_options_map', $page, $header_tab );
		}
	}

	add_action( 'leonie_core_action_default_options_init', 'leonie_core_add_logo_options', leonie_core_get_admin_options_map_position( 'logo' ) );
}
