<?php

if ( ! function_exists( 'leonie_core_add_divided_header_options' ) ) {
	/**
	 * Function that add additional header layout options
	 *
	 * @param object $page
	 * @param array $general_header_tab
	 */
	function leonie_core_add_divided_header_options( $page, $general_header_tab ) {

		$section = $general_header_tab->add_section_element(
			array(
				'name'       => 'qodef_divided_header_section',
				'title'      => esc_html__( 'Divided Header', 'leonie-core' ),
				'dependency' => array(
					'show' => array(
						'qodef_header_layout' => array(
							'values'        => 'divided',
							'default_value' => '',
						),
					),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_divided_header_height',
				'title'       => esc_html__( 'Header Height', 'leonie-core' ),
				'description' => esc_html__( 'Enter header height', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'leonie-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_divided_header_side_padding',
				'title'       => esc_html__( 'Header Side Padding', 'leonie-core' ),
				'description' => esc_html__( 'Enter side padding for header area', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px or %', 'leonie-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_divided_header_background_color',
				'title'       => esc_html__( 'Header Background Color', 'leonie-core' ),
				'description' => esc_html__( 'Enter header background color', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'leonie-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_divided_header_border_color',
				'title'       => esc_html__( 'Header Border Color', 'leonie-core' ),
				'description' => esc_html__( 'Enter header border color', 'leonie-core' ),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_divided_header_border_width',
				'title'       => esc_html__( 'Header Border Width', 'leonie-core' ),
				'description' => esc_html__( 'Enter header border width size', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'leonie-core' ),
				),
			)
		);

		$section->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_divided_header_border_style',
				'title'       => esc_html__( 'Header Border Style', 'leonie-core' ),
				'description' => esc_html__( 'Choose header border style', 'leonie-core' ),
				'options'     => leonie_core_get_select_type_options_pool( 'border_style' ),
			)
		);
	}

	add_action( 'leonie_core_action_after_header_options_map', 'leonie_core_add_divided_header_options', 10, 2 );
}
