<?php

if ( ! function_exists( 'leonie_core_add_top_area_options' ) ) {
	/**
	 * Function that add additional header layout options
	 *
	 * @param object $page
	 * @param array $general_header_tab
	 */
	function leonie_core_add_top_area_options( $page, $general_header_tab ) {

		$top_area_section = $general_header_tab->add_section_element(
			array(
				'name'        => 'qodef_top_area_section',
				'title'       => esc_html__( 'Top Area', 'leonie-core' ),
				'description' => esc_html__( 'Options related to top area', 'leonie-core' ),
				'dependency'  => array(
					'hide' => array(
						'qodef_header_layout' => array(
							'values'        => leonie_core_dependency_for_top_area_options(),
							'default_value' => apply_filters( 'leonie_core_filter_header_layout_default_option_value', '' ),
						),
					),
				),
			)
		);

		$top_area_section->add_field_element(
			array(
				'field_type'    => 'yesno',
				'default_value' => 'no',
				'name'          => 'qodef_top_area_header',
				'title'         => esc_html__( 'Top Area', 'leonie-core' ),
				'description'   => esc_html__( 'Enable top area', 'leonie-core' ),
			)
		);

		$top_area_options_section = $top_area_section->add_section_element(
			array(
				'name'        => 'qodef_top_area_options_section',
				'title'       => esc_html__( 'Top Area Options', 'leonie-core' ),
				'description' => esc_html__( 'Set desired values for top area', 'leonie-core' ),
				'dependency'  => array(
					'show' => array(
						'qodef_top_area_header' => array(
							'values'        => 'yes',
							'default_value' => 'no',
						),
					),
				),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_top_area_header_skin',
				'title'       => esc_html__( 'Top Header Skin', 'leonie-core' ),
				'description' => esc_html__( 'Choose a predefined header style for header elements', 'leonie-core' ),
				'options'     => array(
					'none'  => esc_html__( 'None', 'leonie-core' ),
					'light' => esc_html__( 'Light', 'leonie-core' ),
					'dark'  => esc_html__( 'Dark', 'leonie-core' ),
				),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'    => 'yesno',
				'name'          => 'qodef_top_area_header_in_grid',
				'title'         => esc_html__( 'Content in Grid', 'leonie-core' ),
				'description'   => esc_html__( 'Set content to be in grid', 'leonie-core' ),
				'default_value' => 'no',
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_top_area_header_background_color',
				'title'       => esc_html__( 'Top Area Background Color', 'leonie-core' ),
				'description' => esc_html__( 'Choose top area background color', 'leonie-core' ),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'color',
				'name'        => 'qodef_top_area_header_border_color',
				'title'       => esc_html__( 'Top Header Border Color', 'leonie-core' ),
				'description' => esc_html__( 'Enter top header border color', 'leonie-core' ),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_top_area_header_border_width',
				'title'       => esc_html__( 'Top Header Border Width', 'leonie-core' ),
				'description' => esc_html__( 'Enter top header border width size', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'leonie-core' ),
				),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'select',
				'name'        => 'qodef_top_area_header_border_style',
				'title'       => esc_html__( 'TopHeader Border Style', 'leonie-core' ),
				'description' => esc_html__( 'Choose header border style', 'leonie-core' ),
				'options'     => leonie_core_get_select_type_options_pool( 'border_style' ),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type'  => 'text',
				'name'        => 'qodef_top_area_header_height',
				'title'       => esc_html__( 'Top Area Height', 'leonie-core' ),
				'description' => esc_html__( 'Enter top area height (default is 30px)', 'leonie-core' ),
				'args'        => array(
					'suffix' => esc_html__( 'px', 'leonie-core' ),
				),
			)
		);

		$top_area_options_section->add_field_element(
			array(
				'field_type' => 'text',
				'name'       => 'qodef_top_area_header_side_padding',
				'title'      => esc_html__( 'Top Area Side Padding', 'leonie-core' ),
				'args'       => array(
					'suffix' => esc_html__( 'px or %', 'leonie-core' ),
				),
			)
		);
	}

	add_action( 'leonie_core_action_after_header_options_map', 'leonie_core_add_top_area_options', 20, 2 );
}
