<?php

if ( ! function_exists( 'leonie_core_add_portfolio_project_info_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function leonie_core_add_portfolio_project_info_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Portfolio_Project_Info_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_portfolio_project_info_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Portfolio_Project_Info_Shortcode extends LeonieCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'leonie_core_filter_portfolio_project_info_layouts', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_CPT_URL_PATH . '/portfolio/shortcodes/portfolio-project-info' );
			$this->set_base( 'leonie_core_portfolio_project_info' );
			$this->set_name( esc_html__( 'Portfolio Project Info', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that display list of category items', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'portfolio_id',
					'title'      => esc_html__( 'Portfolio Item ID', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'project_info_type',
					'title'      => esc_html__( 'Project Info Type', 'leonie-core' ),
					'options'    => array(
						'title'    => esc_html__( 'Title', 'leonie-core' ),
						'category' => esc_html__( 'Category', 'leonie-core' ),
						'tag'      => esc_html__( 'Tag', 'leonie-core' ),
						'author'   => esc_html__( 'Author', 'leonie-core' ),
						'date'     => esc_html__( 'Date', 'leonie-core' ),
						'image'    => esc_html__( 'Featured Image', 'leonie-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'project_info_title',
					'title'       => esc_html__( 'Project Info Label', 'leonie-core' ),
					'description' => esc_html__( 'Add project info label before project info element/s', 'leonie-core' ),
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['project_id']     = ! empty( $atts['portfolio_id'] ) ? $atts['portfolio_id'] : get_the_ID();
			$atts['this_shortcode'] = $this;

			return leonie_core_get_template_part( 'post-types/portfolio/shortcodes/portfolio-project-info', 'templates/content', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-portfolio-project-info';

			return implode( ' ', $holder_classes );
		}
	}
}
