<?php

if ( ! function_exists( 'leonie_core_add_banner_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function leonie_core_add_banner_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Banner_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_banner_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Banner_Shortcode extends LeonieCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'leonie_core_filter_banner_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'leonie_core_filter_banner_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_SHORTCODES_URL_PATH . '/banner' );
			$this->set_base( 'leonie_core_banner' );
			$this->set_name( esc_html__( 'Banner', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds banner element', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);

			$options_map = leonie_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'leonie-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'image',
					'title'      => esc_html__( 'Image', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link_url',
					'title'      => esc_html__( 'Link', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'link_target',
					'title'         => esc_html__( 'Link Target', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'content_padding',
					'title'      => esc_html__( 'Content Padding', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'separator',
					'title'         => esc_html__( 'Separator', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title',
					'title'      => esc_html__( 'Title', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h3',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top',
					'title'      => esc_html__( 'Title Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle',
					'title'      => esc_html__( 'Subtitle', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'subtitle_tag',
					'title'         => esc_html__( 'Subtitle Tag', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h5',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_font_size',
					'title'      => esc_html__( 'Subtitle Font Size', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'subtitle_color',
					'title'      => esc_html__( 'Subtitle Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_margin_top',
					'title'      => esc_html__( 'Subtitle Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_field',
					'title'      => esc_html__( 'Text', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'text_tag',
					'title'         => esc_html__( 'Text Tag', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'p',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'text_color',
					'title'      => esc_html__( 'Text Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_top',
					'title'      => esc_html__( 'Text Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_bottom',
					'title'      => esc_html__( 'Text Margin Bottom', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'text_alignment',
					'title'         => esc_html__( 'Text Alignment', 'leonie-core' ),
					'options'       => array(
						''       => esc_html__( 'Default', 'leonie-core' ),
						'left'   => esc_html__( 'Left', 'leonie-core' ),
						'right'  => esc_html__( 'Right', 'leonie-core' ),
						'center' => esc_html__( 'Center', 'leonie-core' ),
					),
					'default_value' => 'h5',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->import_shortcode_options(
				array(
					'shortcode_base'    => 'leonie_core_button',
					'exclude'           => array( 'custom_class', 'link', 'target' ),
					'additional_params' => array(
						'group'      => esc_html__( 'Button', 'leonie-core' ),
						'dependency' => array(
							'show' => array(
								'layout' => array(
									'values'        => 'link-button',
									'default_value' => '',
								),
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'padding_1024',
					'title'      => esc_html__( 'Content Padding', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 1024', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_font_size_1024',
					'title'      => esc_html__( 'Subtitle Font Size', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 1024', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_margin_top_1024',
					'title'      => esc_html__( 'Subtitle Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 1024', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_font_size_1024',
					'title'      => esc_html__( 'Title Font Size', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 1024', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top_1024',
					'title'      => esc_html__( 'Title Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 1024', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'padding_680',
					'title'      => esc_html__( 'Content Padding', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 680', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_font_size_680',
					'title'      => esc_html__( 'Subtitle Font Size', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 680', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_margin_top_680',
					'title'      => esc_html__( 'Subtitle Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 680', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_font_size_680',
					'title'      => esc_html__( 'Title Font Size', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 680', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top_680',
					'title'      => esc_html__( 'Title Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Screen Size 680', 'leonie-core' ),
				)
			);
            $this->set_option(
                array(
                    'field_type'    => 'select',
                    'name'          => 'appear_animation',
                    'title'         => esc_html__( 'Enable Appear Animation', 'leonie-core' ),
                    'options'       => leonie_core_get_select_type_options_pool( 'yes_no', false ),
                    'default_value' => 'no',
                    'group'         => esc_html__( 'Animation Options', 'leonie-core' ),
                )
            );
            $this->set_option(
                array(
                    'field_type' => 'text',
                    'name'       => 'appear_animation_delay',
                    'title'      => esc_html__( 'Appear Animation Delay (ms)', 'leonie-core' ),
                    'dependency' => array(
                        'show' => array(
                            'appear_animation' => array(
                                'values'        => 'yes',
                                'default_value' => 'no',
                            ),
                        ),
                    ),
                    'group'      => esc_html__( 'Animation Options', 'leonie-core' ),
                )
            );
            $this->set_option(
                array(
                    'field_type'    => 'select',
                    'name'          => 'hover_animation',
                    'title'         => esc_html__( 'Enable Hover Animation', 'leonie-core' ),
                    'options'       => leonie_core_get_select_type_options_pool( 'yes_no', false ),
                    'default_value' => 'no',
                    'group'         => esc_html__( 'Animation Options', 'leonie-core' ),
                )
            );
			$this->map_extra_options();
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['content_unique_class']  = 'qodef-banner-content-' . rand( 0, 1000 );
			$atts['title_unique_class']    = 'qodef-banner-title-' . rand( 0, 1000 );
			$atts['subtitle_unique_class'] = 'qodef-banner-subtitle-' . rand( 0, 1000 );

			$atts['holder_classes']   = $this->get_holder_classes( $atts );
			$atts['content_styles']   = $this->get_content_styles( $atts );
			$atts['content_classes']  = $this->get_content_classes( $atts );
			$atts['title_styles']     = $this->get_title_styles( $atts );
			$atts['title_classes']    = $this->get_title_classes( $atts );
			$atts['subtitle_styles']  = $this->get_subtitle_styles( $atts );
			$atts['subtitle_classes'] = $this->get_subtitle_classes( $atts );
			$atts['text_styles']      = $this->get_text_styles( $atts );
			$atts['button_params']    = $this->generate_button_params( $atts );
			$this->set_global_responsive_styles( $atts );
			$this->set_title_responsive_styles( $atts );
			$this->set_subtitle_responsive_styles( $atts );

			return leonie_core_get_template_part( 'shortcodes/banner', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-banner';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['text_alignment'] ) ? 'qodef-text-align--' . $atts['text_alignment'] : '';
			$holder_classes[] = 'no' !== $atts['separator'] ? 'qodef--separator' : '';
            $holder_classes[] = ! empty( $atts['appear_animation'] ) && 'yes' === $atts['appear_animation'] ? 'qodef-appear-animation--enabled' : '';
            $holder_classes[] = ! empty( $atts['hover_animation'] ) && 'yes' === $atts['hover_animation'] ? 'qodef-hover-animation--enabled' : '';

            return implode( ' ', $holder_classes );
		}

		private function get_content_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['content_padding'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['content_padding'] ) ) {
					$styles[] = 'padding: ' . $atts['content_padding'];
				} else {
					$styles[] = 'padding: ' . intval( $atts['content_padding'] ) . 'px';
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}

		private function get_title_classes( $atts ) {
			$title_classes = array();

			$title_classes[] = 'qodef-m-title';
			$title_classes[] = $atts['title_unique_class'];

			return implode( ' ', $title_classes );
		}

		private function get_subtitle_classes( $atts ) {
			$title_classes = array();

			$title_classes[] = 'qodef-m-subtitle';
			$title_classes[] = $atts['subtitle_unique_class'];

			return implode( ' ', $title_classes );
		}

		private function get_content_classes( $atts ) {
			$title_classes = array();

			$title_classes[] = 'qodef-m-content-inner';
			$title_classes[] = $atts['content_unique_class'];

			return implode( ' ', $title_classes );
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['title_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['title_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['title_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['title_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}

		private function get_subtitle_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['subtitle_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['subtitle_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['subtitle_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['subtitle_margin_top'] ) . 'px';
				}
			}

			if ( '' !== $atts['subtitle_font_size'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['subtitle_font_size'] ) ) {
					$styles[] = 'font-size: ' . $atts['subtitle_font_size'];
				} else {
					$styles[] = 'font-size: ' . intval( $atts['subtitle_font_size'] ) . 'px';
				}
			}

			if ( ! empty( $atts['subtitle_color'] ) ) {
				$styles[] = 'color: ' . $atts['subtitle_color'];
			}

			if ( ! empty( $atts['appear_animation_delay'] ) ) {
			    $styles[] = 'transition-delay: ' .$atts['appear_animation_delay'] . 'ms';
            }

			return $styles;
		}

		private function get_text_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['text_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['text_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['text_margin_top'] ) . 'px';
				}
			}

			if ( '' !== $atts['text_margin_bottom'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_bottom'] ) ) {
					$styles[] = 'margin-bottom: ' . $atts['text_margin_bottom'];
				} else {
					$styles[] = 'margin-bottom: ' . intval( $atts['text_margin_bottom'] ) . 'px';
				}
			}

			if ( ! empty( $atts['text_color'] ) ) {
				$styles[] = 'color: ' . $atts['text_color'];
			}

			return $styles;
		}

		private function generate_button_params( $atts ) {
			$params = $this->populate_imported_shortcode_atts(
				array(
					'shortcode_base' => 'leonie_core_button',
					'exclude'        => array( 'custom_class', 'link', 'target' ),
					'atts'           => $atts,
				)
			);

			$params['link']   = ! empty( $atts['link_url'] ) ? $atts['link_url'] : '';
			$params['target'] = ! empty( $atts['link_target'] ) ? $atts['link_target'] : '';

			return $params;
		}

		private function set_global_responsive_styles( $atts ) {
			$unique_class = '.' . $atts['content_unique_class'];
			$screen_sizes = array( '1024', '680' );
			$option_keys  = array( 'padding' );

			foreach ( $screen_sizes as $screen_size ) {
				$styles = array();

				foreach ( $option_keys as $option_key ) {
					$option_value = $atts[ $option_key . '_' . $screen_size ];
					$style_key    = str_replace( '_', '-', $option_key );

					if ( '' !== $option_value ) {
						if ( qode_framework_string_ends_with_typography_units( $option_value ) ) {
							$styles[ $style_key ] = $option_value . '!important';
						} else {
							$styles[ $style_key ] = intval( $option_value ) . 'px !important';
						}
					}
				}

				if ( ! empty( $styles ) ) {
					add_filter(
						'leonie_core_filter_add_responsive_' . $screen_size . '_inline_style_in_footer',
						function ( $style ) use ( $unique_class, $styles ) {
							$style .= qode_framework_dynamic_style( $unique_class, $styles );

							return $style;
						}
					);
				}
			}
		}

		private function set_title_responsive_styles( $atts ) {
			$unique_class = '.' . $atts['title_unique_class'];
			$screen_sizes = array( '1024', '680' );
			$option_keys  = array( 'font_size', 'margin_top' );

			foreach ( $screen_sizes as $screen_size ) {
				$styles = array();

				foreach ( $option_keys as $option_key ) {
					$option_value = $atts[ 'title_' . $option_key . '_' . $screen_size ];
					$style_key    = str_replace( '_', '-', $option_key );

					if ( '' !== $option_value ) {
						if ( qode_framework_string_ends_with_typography_units( $option_value ) ) {
							$styles[ $style_key ] = $option_value . '!important';
						} else {
							$styles[ $style_key ] = intval( $option_value ) . 'px !important';
						}
					}
				}

				if ( ! empty( $styles ) ) {
					add_filter(
						'leonie_core_filter_add_responsive_' . $screen_size . '_inline_style_in_footer',
						function ( $style ) use ( $unique_class, $styles ) {
							$style .= qode_framework_dynamic_style( $unique_class, $styles );

							return $style;
						}
					);
				}
			}
		}

		private function set_subtitle_responsive_styles( $atts ) {
			$unique_class = '.' . $atts['subtitle_unique_class'];
			$screen_sizes = array( '1024', '680' );
			$option_keys  = array( 'font_size', 'margin_top' );

			foreach ( $screen_sizes as $screen_size ) {
				$styles = array();

				foreach ( $option_keys as $option_key ) {
					$option_value = $atts[ 'subtitle_' . $option_key . '_' . $screen_size ];
					$style_key    = str_replace( '_', '-', $option_key );

					if ( '' !== $option_value ) {
						if ( qode_framework_string_ends_with_typography_units( $option_value ) ) {
							$styles[ $style_key ] = $option_value . '!important';
						} else {
							$styles[ $style_key ] = intval( $option_value ) . 'px !important';
						}
					}
				}

				if ( ! empty( $styles ) ) {
					add_filter( 'leonie_core_filter_add_responsive_' . $screen_size . '_inline_style_in_footer', function ( $style ) use ( $unique_class, $styles ) {
						$style .= qode_framework_dynamic_style( $unique_class, $styles );

						return $style;
					} );
				}
			}
		}
	}
}
