<?php

if ( ! function_exists( 'leonie_core_add_image_with_text_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function leonie_core_add_image_with_text_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Image_With_Text_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_image_with_text_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Image_With_Text_Shortcode extends LeonieCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'leonie_core_filter_image_with_text_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'leonie_core_filter_image_with_text_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_SHORTCODES_URL_PATH . '/image-with-text' );
			$this->set_base( 'leonie_core_image_with_text' );
			$this->set_name( esc_html__( 'Image With Text', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds image with text element', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);

			$options_map = leonie_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'leonie-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'image',
					'title'      => esc_html__( 'Main Image', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'first_overlay_image',
					'title'      => esc_html__( 'First Overlay Image', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'second_overlay_image',
					'title'      => esc_html__( 'Second Overlay Image', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'image_size',
					'title'       => esc_html__( 'Image Size', 'leonie-core' ),
					'description' => esc_html__( 'For predefined image sizes input thumbnail, medium, large or full. If you wish to set a custom image size, type in the desired image dimensions in pixels (e.g. 400x400).', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'image_action',
					'title'      => esc_html__( 'Image Action', 'leonie-core' ),
					'options'    => array(
						''            => esc_html__( 'No Action', 'leonie-core' ),
						'open-popup'  => esc_html__( 'Open Popup', 'leonie-core' ),
						'custom-link' => esc_html__( 'Custom Link', 'leonie-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Custom Link', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'dropshadow',
					'title'         => esc_html__( 'Drop Shadow', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'dropshadow_color',
					'title'      => esc_html__( 'Drop Shadow Color', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'dropshadow' => array(
								'values' => 'yes',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title',
					'title'      => esc_html__( 'Title', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h4',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top',
					'title'      => esc_html__( 'Title Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle',
					'title'      => esc_html__( 'Subtitle', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'subtitle_color',
					'title'      => esc_html__( 'Subtitle Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'subtitle_margin_top',
					'title'      => esc_html__( 'Subtitle Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'textarea',
					'name'       => 'text',
					'title'      => esc_html__( 'Text', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'text_color',
					'title'      => esc_html__( 'Text Color', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_top',
					'title'      => esc_html__( 'Text Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'content_align',
					'title'         => esc_html__( 'Content Align', 'leonie-core' ),
					'options'       => array(
						'center' => esc_html__( 'Center', 'leonie-core' ),
						'left'   => esc_html__( 'Left', 'leonie-core' ),
						'right'  => esc_html__( 'Right', 'leonie-core' ),
					),
					'default_value' => 'center',
					'group'         => esc_html__( 'Content', 'leonie-core' ),
				)
			);
			$this->set_option(
			    array(
			        'field_type'    => 'select',
                    'name'          => 'appear_animation',
                    'title'         => esc_html__( 'Enable Appear Animation', 'leonie-core' ),
                    'options'       => leonie_core_get_select_type_options_pool( 'no_yes', false ),
                    'default_value' => 'no',
                    'group'         => esc_html__( 'Animation Options', 'leonie-core' )
                )
            );
            $this->set_option(
                array(
                    'field_type' => 'text',
                    'name'       => 'appear_animation_delay',
                    'title'      => esc_html__( 'Appear Animation Delay (ms)', 'leonie-core' ),
                    'group'      => esc_html__( 'Animation Options', 'leonie-core' )
                )
            );
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'leonie_core_image_with_text', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes']      = $this->get_holder_classes( $atts );
			$atts['title_styles']        = $this->get_title_styles( $atts );
			$atts['shadow_styles']       = $this->get_shadow_styles( $atts );
			$atts['subtitle_styles']     = $this->get_subtitle_styles( $atts );
			$atts['text_styles']         = $this->get_text_styles( $atts );
			$atts['main_image_params']   = $this->generate_main_image_params( $atts );
			$atts['first_image_params']  = $this->generate_first_image_params( $atts );
			$atts['second_image_params'] = $this->generate_second_image_params( $atts );
			$atts['animation_styles']    = $this->get_animation_styles( $atts );

			return leonie_core_get_template_part( 'shortcodes/image-with-text', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-image-with-text';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ( 'yes' === $atts['dropshadow'] ) ? 'qodef--dropshadow' : '';
			$holder_classes[] = ! empty( $atts['content_align'] ) ? 'qodef-content-align--' . $atts['content_align'] : '';
			$holder_classes[] = ! empty( $atts['appear_animation'] ) && 'yes' === $atts['appear_animation'] ? 'qodef-appear-animation--enabled' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['title_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['title_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['title_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['title_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}

		private function get_shadow_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['dropshadow_color'] ) ) {
				$styles[] = 'color: ' . $atts['dropshadow_color'];
			}

			return $styles;
		}

		private function get_subtitle_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['subtitle_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['subtitle_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['subtitle_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['subtitle_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['subtitle_color'] ) ) {
				$styles[] = 'color: ' . $atts['subtitle_color'];
			}

			return $styles;
		}

		private function get_text_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['text_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['text_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['text_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['text_color'] ) ) {
				$styles[] = 'color: ' . $atts['text_color'];
			}

			return $styles;
		}

		private function generate_main_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['image'] ) ) {
				$id = $atts['image'];

				$image['image_id'] = intval( $id );
				$image_original    = wp_get_attachment_image_src( $id, 'full' );
				$image['url']      = $image_original[0];
				$image['alt']      = get_post_meta( $id, '_wp_attachment_image_alt', true );

				$image_size = trim( $atts['image_size'] );
				preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
				if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
					$image['image_size'] = $image_size;
				} elseif ( ! empty( $matches[0] ) ) {
					$image['image_size'] = array(
						$matches[0][0],
						$matches[0][1],
					);
				} else {
					$image['image_size'] = 'full';
				}
			}

			return $image;
		}

		private function generate_first_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['first_overlay_image'] ) ) {
				$id                = $atts['first_overlay_image'];
				$image['image_id'] = intval( $id );

				$image_size = trim( $atts['image_size'] );
				preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
				if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
					$image['image_size'] = $image_size;
				} elseif ( ! empty( $matches[0] ) ) {
					$image['image_size'] = array(
						$matches[0][0],
						$matches[0][1],
					);
				} else {
					$image['image_size'] = 'full';
				}
			}

			return $image;
		}

		private function generate_second_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['second_overlay_image'] ) ) {
				$id                = $atts['second_overlay_image'];
				$image['image_id'] = intval( $id );

				$image_size = trim( $atts['image_size'] );
				preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
				if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
					$image['image_size'] = $image_size;
				} elseif ( ! empty( $matches[0] ) ) {
					$image['image_size'] = array(
						$matches[0][0],
						$matches[0][1],
					);
				} else {
					$image['image_size'] = 'full';
				}
			}

			return $image;
		}

		private function get_animation_styles( $atts ) {
            $styles = array();

            if ( ! empty( $atts['appear_animation_delay'] ) ) {
                $styles[] = 'transition-delay: ' . $atts['appear_animation_delay'] . 'ms';
            }

            return $styles;
        }
	}
}
