<?php

if ( ! function_exists( 'leonie_core_add_pricing_list_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function leonie_core_add_pricing_list_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Pricing_List_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_pricing_list_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Pricing_List_Shortcode extends LeonieCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_SHORTCODES_URL_PATH . '/pricing-list' );
			$this->set_base( 'leonie_core_pricing_list' );
			$this->set_name( esc_html__( 'Pricing List', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds pricing list element', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'skin',
					'title'      => esc_html__( 'Light Skin', 'leonie-core' ),
					'options'    => leonie_core_get_select_type_options_pool( 'no_yes', false ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Child elements', 'leonie-core' ),
					'items'      => array(
						array(
							'field_type' => 'text',
							'name'       => 'title',
							'title'      => esc_html__( 'Title', 'leonie-core' ),
						),
						array(
							'field_type' => 'textarea',
							'name'       => 'text',
							'title'      => esc_html__( 'Text', 'leonie-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'price',
							'title'      => esc_html__( 'Price', 'leonie-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'price_label',
							'title'      => esc_html__( 'Old Price', 'leonie-core' ),
						),
					),
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );
			$atts['this_shortcode'] = $this;

			return leonie_core_get_template_part( 'shortcodes/pricing-list', 'templates/holder', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-pricing-list';
			$holder_classes[] = 'yes' === $atts['skin'] ? 'qodef--light' : '';

			return implode( ' ', $holder_classes );
		}
	}
}
