<?php

if ( ! function_exists( 'leonie_core_add_section_title_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function leonie_core_add_section_title_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Section_Title_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_section_title_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Section_Title_Shortcode extends LeonieCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_SHORTCODES_URL_PATH . '/section-title' );
			$this->set_base( 'leonie_core_section_title' );
			$this->set_name( esc_html__( 'Section Title', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds section title element', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'tagline',
					'title'      => esc_html__( 'Tagline', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'separator_position',
					'title'       => esc_html__( 'Positions of Separator', 'leonie-core' ),
					'description' => esc_html__( 'Enter the positions of the words after which you would like to create a separator. Separate the positions with commas (e.g. if you would like the first, third, and fourth word to have a line break, you would enter "1,3,4")', 'leonie-core' ),
					'group'       => esc_html__( 'Tagline Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'tagline_color',
					'title'      => esc_html__( 'Tagline Color', 'leonie-core' ),
					'group'      => esc_html__( 'Tagline Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title',
					'title'      => esc_html__( 'Title', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'line_break_positions',
					'title'       => esc_html__( 'Positions of Line Break', 'leonie-core' ),
					'description' => esc_html__( 'Enter the positions of the words after which you would like to create a line break. Separate the positions with commas (e.g. if you would like the first, third, and fourth word to have a line break, you would enter "1,3,4")', 'leonie-core' ),
					'group'       => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'disable_title_break_words',
					'title'         => esc_html__( 'Disable Title Line Break', 'leonie-core' ),
					'description'   => esc_html__( 'Enabling this option will disable title line breaks for screen size 1024 and lower', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h2',
					'group'         => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'leonie-core' ),
					'group'      => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'title_margin_top',
					'title'      => esc_html__( 'Title Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Title Custom Link', 'leonie-core' ),
					'group'      => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
					'group'         => esc_html__( 'Title Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'textarea',
					'name'       => 'text',
					'title'      => esc_html__( 'Text', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'text_color',
					'title'      => esc_html__( 'Text Color', 'leonie-core' ),
					'group'      => esc_html__( 'Text Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'text_margin_top',
					'title'      => esc_html__( 'Text Margin Top', 'leonie-core' ),
					'group'      => esc_html__( 'Text Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'content_alignment',
					'title'      => esc_html__( 'Content Alignment', 'leonie-core' ),
					'options'    => array(
						''       => esc_html__( 'Default', 'leonie-core' ),
						'left'   => esc_html__( 'Left', 'leonie-core' ),
						'center' => esc_html__( 'Center', 'leonie-core' ),
						'right'  => esc_html__( 'Right', 'leonie-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'button_text',
					'title'      => esc_html__( 'Button Text', 'leonie-core' ),
					'default'    => esc_html__( 'Read more', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'button_margin',
					'title'      => esc_html__( 'Button Margin', 'leonie-core' ),
					'group'      => esc_html__( 'Button Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'button_layout',
					'title'      => esc_html__( 'Button Layout', 'leonie-core' ),
					'options'    => array(
						'filled'   => esc_html__( 'Filled', 'leonie-core' ),
						'outlined' => esc_html__( 'Outlined', 'leonie-core' ),
						'textual'  => esc_html__( 'Textual', 'leonie-core' ),
					),
					'group'      => esc_html__( 'Button Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'button_skin',
					'title'      => esc_html__( 'Button Skin', 'leonie-core' ),
					'options'    => array(
						'default' => esc_html__( 'Default', 'leonie-core' ),
						'light'   => esc_html__( 'Light', 'leonie-core' ),
						'dark'    => esc_html__( 'Dark', 'leonie-core' ),
					),
					'group'      => esc_html__( 'Button Style', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'button_link',
					'title'      => esc_html__( 'Button Link', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'button_target',
					'title'         => esc_html__( 'Target', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
				)
			);

		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['title']          = $this->get_modified_title( $atts );
			$atts['tagline']        = $this->get_modified_tagline( $atts );
			$atts['title_styles']   = $this->get_title_styles( $atts );
			$atts['tagline_styles'] = $this->get_tagline_styles( $atts );
			$atts['text_styles']    = $this->get_text_styles( $atts );
			$atts['button_params']  = $this->get_button_params( $atts );

			return leonie_core_get_template_part( 'shortcodes/section-title', 'templates/section-title', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-section-title';
			$holder_classes[] = ! empty( $atts['content_alignment'] ) ? 'qodef-alignment--' . $atts['content_alignment'] : 'qodef-alignment--left';
			$holder_classes[] = 'yes' === $atts['disable_title_break_words'] ? 'qodef-title-break--disabled' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_modified_tagline( $atts ) {
			$tagline = $atts['tagline'];

			if ( ! empty( $tagline ) && ! empty( $atts['separator_position'] ) ) {
				$split_tagline      = explode( ' ', $tagline );
				$separator_position = explode( ',', str_replace( ' ', '', $atts['separator_position'] ) );

				foreach ( $separator_position as $position ) {
					$position = intval( $position );
					if ( isset( $split_tagline[ $position - 1 ] ) && ! empty( $split_tagline[ $position - 1 ] ) ) {
						$split_tagline[ $position - 1 ] = $split_tagline[ $position - 1 ] . '<span class="qodef-tagline-separator"></span>';
					}
				}

				$tagline = implode( ' ', $split_tagline );
			}

			return $tagline;
		}

		private function get_modified_title( $atts ) {
			$title = $atts['title'];

			if ( ! empty( $title ) && ! empty( $atts['line_break_positions'] ) ) {
				$split_title          = explode( ' ', $title );
				$line_break_positions = explode( ',', str_replace( ' ', '', $atts['line_break_positions'] ) );

				foreach ( $line_break_positions as $position ) {
					$position = intval( $position );
					if ( isset( $split_title[ $position - 1 ] ) && ! empty( $split_title[ $position - 1 ] ) ) {
						$split_title[ $position - 1 ] = $split_title[ $position - 1 ] . '<br />';
					}
				}

				$title = implode( ' ', $split_title );
			}

			return $title;
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			if ( '' !== $atts['title_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['title_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['title_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['title_margin_top'] ) . 'px';
				}
			}

			return $styles;
		}

		private function get_tagline_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['tagline_color'] ) ) {
				$styles[] = 'color: ' . $atts['tagline_color'];
			}

			return $styles;
		}

		private function get_text_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['text_margin_top'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['text_margin_top'] ) ) {
					$styles[] = 'margin-top: ' . $atts['text_margin_top'];
				} else {
					$styles[] = 'margin-top: ' . intval( $atts['text_margin_top'] ) . 'px';
				}
			}

			if ( ! empty( $atts['text_color'] ) ) {
				$styles[] = 'color: ' . $atts['text_color'];
			}

			return $styles;
		}

		private function get_button_params( $atts ) {
			$color = $hover_color = $background_color = $hover_background_color = $border_color = '';

			if ( 'outlined' === $atts['button_layout'] ) {
				if ( 'default' === $atts['button_skin'] ) {
					$color                  = '#000';
					$hover_color            = '#fff';
					$border_color           = '#000';
					$background_color       = 'transparent';
					$hover_background_color = '#000';

				}
				if ( 'dark' === $atts['button_skin'] ) {
					$color                  = '#000';
					$hover_color            = '#fff';
					$border_color           = '#000';
					$background_color       = 'transparent';
					$hover_background_color = '#000';
				}
				if ( 'light' === $atts['button_skin'] ) {
					$color                  = '#fff';
					$hover_color            = '#000';
					$border_color           = '#fff';
					$background_color       = 'transparent';
					$hover_background_color = '#fff';
				}
			}

			if ( 'textual' === $atts['button_layout'] ) {
				$color = '#161616';
			}

			$params = array(
				'button_layout'          => $atts['button_layout'],
				'text'                   => $atts['button_text'],
				'margin'                 => $atts['button_margin'],
				'link'                   => $atts['button_link'],
				'target'                 => $atts['button_target'],
				'color'                  => $color,
				'hover_color'            => $hover_color,
				'background_color'       => $background_color,
				'border_color'           => $border_color,
				'hover_background_color' => $hover_background_color,
			);

			return $params;
		}
	}
}
