<?php

if ( ! function_exists( 'leonie_core_add_single_image_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param $shortcodes array
	 *
	 * @return array
	 */
	function leonie_core_add_single_image_shortcode( $shortcodes ) {
		$shortcodes[] = 'LeonieCore_Single_Image_Shortcode';

		return $shortcodes;
	}

	add_filter( 'leonie_core_filter_register_shortcodes', 'leonie_core_add_single_image_shortcode' );
}

if ( class_exists( 'LeonieCore_Shortcode' ) ) {
	class LeonieCore_Single_Image_Shortcode extends LeonieCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'leonie_core_filter_single_image_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'leonie_core_filter_single_image_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( LEONIE_CORE_SHORTCODES_URL_PATH . '/single-image' );
			$this->set_base( 'leonie_core_single_image' );
			$this->set_name( esc_html__( 'Single Image', 'leonie-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds image element', 'leonie-core' ) );
			$this->set_category( esc_html__( 'Leonie Core', 'leonie-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'leonie-core' ),
				)
			);

			$options_map = leonie_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'leonie-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => $options_map['default_value'],
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'image',
					'title'      => esc_html__( 'Image', 'leonie-core' ),
				)
			);

			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'image_size',
					'title'       => esc_html__( 'Image Size', 'leonie-core' ),
					'description' => esc_html__( 'For predefined image sizes input thumbnail, medium, large or full. If you wish to set a custom image size, type in the desired image dimensions in pixels (e.g. 400x400).', 'leonie-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'image_action',
					'title'      => esc_html__( 'Image Action', 'leonie-core' ),
					'options'    => array(
						''            => esc_html__( 'No Action', 'leonie-core' ),
						'open-popup'  => esc_html__( 'Open Popup', 'leonie-core' ),
						'custom-link' => esc_html__( 'Custom Link', 'leonie-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'link',
					'title'      => esc_html__( 'Custom Link', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'image_action' => array(
								'values'        => array( 'custom-link' ),
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'target',
					'title'         => esc_html__( 'Custom Link Target', 'leonie-core' ),
					'options'       => leonie_core_get_select_type_options_pool( 'link_target' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'image_action' => array(
								'values'        => 'custom-link',
								'default_value' => '',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'image_align',
					'title'         => esc_html__( 'Image Align', 'leonie-core' ),
					'options'       => array(
						'center' => esc_html__( 'Center', 'leonie-core' ),
						'left'   => esc_html__( 'Left', 'leonie-core' ),
						'right'  => esc_html__( 'Right', 'leonie-core' ),
					),
					'default_value' => 'left',
				)
			);
            $this->set_option(
                array(
                    'field_type'    => 'select',
                    'name'          => 'appear_animation',
                    'title'         => esc_html__( 'Appear Animation', 'leonie-core' ),
                    'options'       => array(
                        'none'       => esc_html__( 'None', 'leonie-core' ),
                        'from-left'  => esc_html__( 'From Left', 'leonie-core' ),
                        'from-right' => esc_html__( 'From Right', 'leonie-core' ),
                        'from-top'   => esc_html__( 'From Top', 'leonie-core' ),
                    ),
                    'default_value' => 'none',
                    'group'         => esc_html__( 'Animation Options', 'leonie-core' )
                )
            );
            $this->set_option(
                array(
                    'field_type' => 'text',
                    'name'       => 'appear_animation_delay',
                    'title'      => esc_html__( 'Appear Animation Delay (ms)', 'leonie-core' ),
                    'group'      => esc_html__( 'Animation Options', 'leonie-core' )
                )
            );
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'leonie_core_single_image', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes']   = $this->get_holder_classes( $atts );
			$atts['image_params']     = $this->generate_image_params( $atts );
            $atts['animation_styles'] = $this->get_animation_styles( $atts );

			return leonie_core_get_template_part( 'shortcodes/single-image', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-single-image';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['image_action'] ) && 'open-popup' === $atts['image_action'] ? 'qodef-magnific-popup qodef-popup-gallery' : '';
			$holder_classes[] = ! empty( $atts['image_align'] ) ? 'qodef-image-align--' . $atts['image_align'] : '';
            $holder_classes[] = ! empty( $atts['appear_animation'] ) ? 'qodef-appear-animation--' . $atts['appear_animation'] : '';

			return implode( ' ', $holder_classes );
		}

		private function generate_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['image'] ) ) {
				$id = $atts['image'];

				$image['image_id'] = intval( $id );
				$image_original    = wp_get_attachment_image_src( $id, 'full' );
				$image['url']      = $image_original[0];
				$image['alt']      = get_post_meta( $id, '_wp_attachment_image_alt', true );

				$image_size = trim( $atts['image_size'] );
				preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
				if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
					$image['image_size'] = $image_size;
				} elseif ( ! empty( $matches[0] ) ) {
					$image['image_size'] = array(
						$matches[0][0],
						$matches[0][1],
					);
				} else {
					$image['image_size'] = 'full';
				}
			}

			return $image;
		}

        private function get_animation_styles( $atts ) {
            $styles = array();

            if ( ! empty( $atts['appear_animation_delay'] ) ) {
                $styles[] = 'transition-delay: ' . $atts['appear_animation_delay'] . 'ms';
            }

            return $styles;
        }
	}
}
