(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefSideArea.init();
		}
	);

	var qodefSideArea = {
		init: function () {
			var $sideAreaOpener  = $( 'a.qodef-side-area-opener' ),
				$sideAreaClose   = $( '#qodef-side-area-close' ),
				$sideArea        = $( '#qodef-side-area' ),
				$closeOverlay    = $('#qodef-side-area .qodef-side-area-overlay-close-holder'),
				$predefinedClose = $('#qodef-side-area-close').first();

			qodefSideArea.openerHoverColor( $sideAreaOpener );

			// Open Side Area
			$sideAreaOpener.on(
				'click',
				function ( e ) {
					e.preventDefault();

					if ( ! qodefCore.body.hasClass( 'qodef-side-area--opened' ) ) {
						$predefinedClose.length ? qodefSideArea.resetCursorPosition($predefinedClose, $sideAreaOpener) : null;
						$predefinedClose.length ? $predefinedClose.addClass('qodef--active') : null;
						qodefSideArea.openSideArea();

						$( document ).keyup(
							function ( e ) {
								if ( e.keyCode === 27 ) {
									$predefinedClose.length ? $predefinedClose.removeClass('qodef--active') : null;
									qodefSideArea.closeSideArea();
								}
							}
						);
					} else {
						$predefinedClose.length ? $predefinedClose.removeClass('qodef--active') : null;
						qodefSideArea.closeSideArea();
					}
					
					$closeOverlay.one('click', function() {
						$predefinedClose.length ? $predefinedClose.removeClass('qodef--active') : null;
						setTimeout(qodefSideArea.closeSideArea(), 100);
					});
				}
			);
			
			if ($sideAreaOpener.hasClass('qodef-source--predefined')) {
				if (qodef.windowWidth > 1024) {
					qodefSideArea.initCloseCursor($predefinedClose, $closeOverlay);
				}
			}

			$sideAreaClose.on(
				'click',
				function ( e ) {
					e.preventDefault();
					qodefSideArea.closeSideArea();
				}
			);

			if ( $sideArea.length && typeof qodefCore.qodefPerfectScrollbar === 'object' ) {
				qodefCore.qodefPerfectScrollbar.init( $sideArea );
			}
		},
		initCloseCursor: function($holder, $overlay) {
			$holder.appendTo($('#qodef-side-area')).addClass('qodef-fs-close-cursor');
			var $fsCloseCursor = $('.qodef-fs-close-cursor');
			$overlay.on('mouseenter', function() {
				$fsCloseCursor.addClass('qodef--active');
			}).on('mouseleave', function() {
				$fsCloseCursor.removeClass('qodef--active');
			});
			
			$(window).on('mousemove', function (e) {
				if ($fsCloseCursor.hasClass('qodef--active')) {
					var x = e.offsetX,
						y = e.offsetY;
					
					TweenMax.to($fsCloseCursor, .5,
						{
							x: x,
							y: y,
							ease: Power3.easeOut,
						}
					);
				}
			});
		},
		resetCursorPosition: function($cursor, $menuOpener) {
			TweenMax.set($cursor,
				{
					x: $menuOpener.offset().left + 27,
					y: $menuOpener.offset().top + 5,
				}
			);
		},
		openSideArea: function () {
			var $wrapper      = $( '#qodef-page-wrapper' );
			var currentScroll = $( window ).scrollTop();

			$( '.qodef-side-area-cover' ).remove();
			$wrapper.prepend( '<div class="qodef-side-area-cover"/>' );
			qodefCore.body.removeClass( 'qodef-side-area-animate--out' ).addClass( 'qodef-side-area--opened qodef-side-area-animate--in' );

			$( '.qodef-side-area-cover' ).on(
				'click',
				function ( e ) {
					e.preventDefault();
					qodefSideArea.closeSideArea();
				}
			);

			$( window ).scroll(
				function () {
					if ( Math.abs( qodefCore.scroll - currentScroll ) > 400 ) {
						qodefSideArea.closeSideArea();
					}
				}
			);
		},
		closeSideArea: function () {
			qodefCore.body.removeClass( 'qodef-side-area--opened qodef-side-area-animate--in' ).addClass( 'qodef-side-area-animate--out' );
		},
		openerHoverColor: function ( $opener ) {
			if ( typeof $opener.data( 'hover-color' ) !== 'undefined' ) {
				var hoverColor    = $opener.data( 'hover-color' );
				var originalColor = $opener.css( 'color' );

				$opener.on(
					'mouseenter',
					function () {
						$opener.css( 'color', hoverColor );
					}
				).on(
					'mouseleave',
					function () {
						$opener.css( 'color', originalColor );
					}
				);
			}
		}
	};

})( jQuery );
