<?php

if ( ! function_exists( 'leonie_core_add_working_hours_options' ) ) {
	/**
	 * Function that add general options for this module
	 */
	function leonie_core_add_working_hours_options() {
		$qode_framework = qode_framework_get_framework_root();

		$page = $qode_framework->add_options_page(
			array(
				'scope'       => LEONIE_CORE_OPTIONS_NAME,
				'type'        => 'admin',
				'slug'        => 'working-hours',
				'icon'        => 'fa fa-book',
				'title'       => esc_html__( 'Working Hours', 'leonie-core' ),
				'description' => esc_html__( 'Global Working Hours Options', 'leonie-core' ),
			)
		);

		if ( $page ) {
			$page->add_field_element(
				array(
					'field_type'    => 'select',
					'name'          => 'qodef_working_hours_layout',
					'options'       => array(
						'all-days'   => esc_html__( 'All Days', 'leonie-core' ),
						'split-days' => esc_html__( 'Split Days', 'leonie-core' ),
					),
					'default_value' => 'split-days',
					'title'         => esc_html__( 'Working Hours Layout', 'leonie-core' ),
				)
			);
			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_monday',
					'title'      => esc_html__( 'Working Hours For Monday', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'all-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_tuesday',
					'title'      => esc_html__( 'Working Hours For Tuesday', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'all-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_wednesday',
					'title'      => esc_html__( 'Working Hours For Wednesday', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'all-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_thursday',
					'title'      => esc_html__( 'Working Hours For Thursday', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'all-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_friday',
					'title'      => esc_html__( 'Working Hours For Friday', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'all-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_mon_fri',
					'title'      => esc_html__( 'Working Hours For Mon - Fri', 'leonie-core' ),
					'dependency' => array(
						'show' => array(
							'qodef_working_hours_layout' => array(
								'values'        => 'split-days',
								'default_value' => 'split-days',
							),
						),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_saturday',
					'title'      => esc_html__( 'Working Hours For Saturday', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_sunday',
					'title'      => esc_html__( 'Working Hours For Sunday', 'leonie-core' ),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'checkbox',
					'name'       => 'qodef_working_hours_special_days',
					'title'      => esc_html__( 'Special Days', 'leonie-core' ),
					'options'    => array(
						'monday'       => esc_html__( 'Monday', 'leonie-core' ),
						'tuesday'      => esc_html__( 'Tuesday', 'leonie-core' ),
						'wednesday'    => esc_html__( 'Wednesday', 'leonie-core' ),
						'thursday'     => esc_html__( 'Thursday', 'leonie-core' ),
						'friday'       => esc_html__( 'Friday', 'leonie-core' ),
						'saturday'     => esc_html__( 'Saturday', 'leonie-core' ),
						'sunday'       => esc_html__( 'Sunday', 'leonie-core' ),
						'working_days' => esc_html__( 'Mon - Fri', 'leonie-core' ),
					),
				)
			);

			$page->add_field_element(
				array(
					'field_type' => 'text',
					'name'       => 'qodef_working_hours_special_text',
					'title'      => esc_html__( 'Featured Text For Special Days', 'leonie-core' ),
				)
			);

			// Hook to include additional options after module options
			do_action( 'leonie_core_action_after_working_hours_options_map', $page );
		}
	}

	add_action( 'leonie_core_action_default_options_init', 'leonie_core_add_working_hours_options', leonie_core_get_admin_options_map_position( 'working-hours' ) );
}
